@@ -1,6 +1,6 @@
 /*
 
- $Id: ssmtp.c,v 2.58 2002/10/25 09:37:25 matt Exp matt $
+ $Id: ssmtp.c,v 2.60 2003/08/17 14:17:57 matt Exp $
 
  sSMTP -- send messages via SMTP to a mailhub for local delivery or forwarding.
  This program is used in place of /usr/sbin/sendmail, called by "mail" (et all).
@@ -12,7 +12,7 @@
  See COPYRIGHT for the license
 
 */
-#define VERSION "2.60.1"
+#define VERSION "2.60.4"
 
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -422,8 +422,8 @@ char *from_strip(char *str)
 	(void)fprintf(stderr, "*** from_strip(): str = [%s]\n", str);
 #endif
 
-	if(strncmp("From: ", str, 6) == 0) {
-		str += 6;
+	if(strncmp("From:", str, 5) == 0) {
+		str += 5;
 	}
 
 	/* Remove the real name if necessary - just send the address */
@@ -488,6 +488,7 @@ void rcpt_save(char *str)
 {
 	char *p;
 
+# if 1
 	/* Horrible botch for group stuff */
 	p = str;
 	while(*p) p++;
@@ -495,11 +496,17 @@ void rcpt_save(char *str)
 	if(*--p == ';') {
 		return;
 	}
+#endif
 
 #if 0
 	(void)fprintf(stderr, "*** rcpt_save(): str = [%s]\n", str);
 #endif
 
+	/* Ignore missing usernames */
+	if(*str == (char)NULL) {
+		return;
+	}
+
 	if((rt->string = strdup(str)) == (char *)NULL) {
 		die("rcpt_save() -- strdup() failed");
 	}
@@ -681,15 +688,15 @@ void header_save(char *str)
 	if(minus_t) {
 		/* Need to figure out recipients from the e-mail */
 		if(strncasecmp(ht->string, "To:", 3) == 0) {
-			p = (ht->string + 4);
+			p = (ht->string + 3);
 			rcpt_parse(p);
 		}
 		else if(strncasecmp(ht->string, "Bcc:", 4) == 0) {
-			p = (ht->string + 5);
+			p = (ht->string + 4);
 			rcpt_parse(p);
 		}
 		else if(strncasecmp(ht->string, "CC:", 3) == 0) {
-			p = (ht->string + 4);
+			p = (ht->string + 3);
 			rcpt_parse(p);
 		}
 	}
@@ -1224,6 +1231,11 @@ int ssmtp(char *argv[])
 
 	header_parse(stdin);
 
+#if 1
+	/* With FromLineOverride=YES set, try to recover sane MAIL FROM address */
+	uad = append_domain(uad);
+#endif
+
 	from = from_format(uad, override_from);
 
 	/* Now to the delivery of the message */
